internal_NrOfXMLNodes: This function is an internal function to count the Number of nodes and child nodes of an XMLNode.
Description
This function is an internal function to count the Number
of nodes and child nodes of an XMLNode.
Usage
internal_NrOfXMLNodes(myXMLNode)
Arguments
myXMLNode
XMLNode to analyze
Value
This function returns the number of Nodes and child Nodes
an XMLNode has.